@@ -20,8 +20,8 @@ class RedisContainer(Container):
         super().__init__(image=image, command=command)
 
     def get_connection_url(self) -> str:
-        ip = self.get_host_ip()
-        port = self.get_exposed_port(self.REDIS_PORT)
+        ip = self.get_container_ip()
+        port = self.get_container_port(self.REDIS_PORT)
         auth = ""
         if self.password:
             auth = f":{self.password}@"
